@@ -183,8 +183,6 @@ char        *EmbedPrivate::sCompPath    = nsnull;
 nsVoidArray *EmbedPrivate::sWindowList  = nsnull;
 nsILocalFile *EmbedPrivate::sProfileDir  = nsnull;
 nsISupports  *EmbedPrivate::sProfileLock = nsnull;
-GtkWidget   *EmbedPrivate::sOffscreenWindow = 0;
-GtkWidget   *EmbedPrivate::sOffscreenFixed  = 0;
 
 nsIDirectoryServiceProvider *EmbedPrivate::sAppFileLocProvider = nsnull;
 
@@ -306,7 +304,6 @@ EmbedPrivate::EmbedPrivate(void)
   mChromeLoaded     = PR_FALSE;
   mLoadFinished     = PR_TRUE;
   mListenersAttached = PR_FALSE;
-  mMozWindowWidget  = 0;
   mIsDestroyed      = PR_FALSE;
   mOpenBlock        = PR_FALSE;
   mIsUploading      = PR_FALSE;
@@ -334,7 +331,7 @@ EmbedPrivate::~EmbedPrivate()
   if (sWidgetCount) return;
   ULOG_INFO("Destroy last window:%p", this);
   gboolean bval = FALSE;
-  if (gtk_moz_embed_common_get_pref (G_TYPE_BOOLEAN,"gtkmozembed.no_destroy_on_last_window", &bval) && bval)
+  if (gtk_moz_embed_common_get_pref (G_TYPE_BOOLEAN, (gchar*)"gtkmozembed.no_destroy_on_last_window", &bval) && bval)
     return;
 
   int pid = getpid();
@@ -415,19 +412,8 @@ EmbedPrivate::Realize(PRBool *aAlreadyRealized, PRBool notRealized)
 
   *aAlreadyRealized = PR_FALSE;
 
-  // create the offscreen window if we have to
-  if (!notRealized)
-    EnsureOffscreenWindow();
 
-  // Have we ever been initialized before?  If so then just reparent
-  // from the offscreen window.
-  if (mMozWindowWidget && mInitialized) {
-    if (mMozWindowWidget)
-      gtk_widget_reparent(mMozWindowWidget, GTK_WIDGET(mOwningWidget));
-    *aAlreadyRealized = PR_TRUE;
     mInitialized = PR_TRUE;
-    return NS_OK;
-  }
 
   // Get the nsIWebBrowser object for our embedded window.
   nsCOMPtr<nsIWebBrowser> webBrowser;
@@ -461,22 +447,6 @@ EmbedPrivate::Realize(PRBool *aAlreadyRealized, PRBool notRealized)
   uriListener = do_QueryInterface(mContentListenerGuard);
   webBrowser->SetParentURIContentListener(uriListener);
 
-  // save the window id of the newly created window
-  nsCOMPtr<nsIWidget> mozWidget;
-  mWindow->mBaseWindow->GetMainWidget(getter_AddRefs(mozWidget));
-  // get the native drawing area
-  GdkWindow *tmp_window =
-    static_cast<GdkWindow *>(
-		   mozWidget->GetNativeData(NS_NATIVE_WINDOW));
-  // and, thanks to superwin we actually need the parent of that.
-  if (tmp_window) {
-    tmp_window = gdk_window_get_parent(tmp_window);
-    // save the widget ID - it should be the mozarea of the window.
-    gpointer data = nsnull;
-    gdk_window_get_user_data(tmp_window, &data);
-    mMozWindowWidget = static_cast<GtkWidget *>(data);
-  }
-
   // Apply the current chrome mask
   ApplyChromeMask();
 
@@ -488,9 +458,6 @@ EmbedPrivate::Realize(PRBool *aAlreadyRealized, PRBool notRealized)
 void
 EmbedPrivate::Unrealize(void)
 {
-  // reparent to our offscreen window
-  if (mMozWindowWidget && sOffscreenFixed)
-    gtk_widget_reparent(mMozWindowWidget, sOffscreenFixed);
   mInitialized = PR_FALSE;
 }
 
@@ -592,8 +559,6 @@ EmbedPrivate::Destroy(void)
   mSessionHistory = nsnull;
 
   mOwningWidget = nsnull;
-
-  mMozWindowWidget = 0;
 }
 
 void
@@ -747,9 +712,6 @@ EmbedPrivate::PopStartup(void)
   EmbedCommon::DeleteInstance();
 
   NS_IF_RELEASE(sCacheService);
-  // destroy the offscreen window
-  ULOG_INFO("Destroy Offscreen window");
-  DestroyOffscreenWindow();
 
   // we no longer need a reference to the DirectoryServiceProvider
   if (sAppFileLocProvider) {
@@ -984,6 +946,7 @@ EmbedPrivate::ContentFinishedLoading(void)
     // We're done loading.
     mChromeLoaded = PR_TRUE;
 
+    NS_ENSURE_TRUE(mWindow, );
     // get the web browser
     nsCOMPtr<nsIWebBrowser> webBrowser;
     mWindow->GetWebBrowser(getter_AddRefs(webBrowser));
@@ -1330,29 +1293,6 @@ EmbedPrivate::RegisterAppComponents(void)
   return rv;
 }
 
-/* static */
-void
-EmbedPrivate::EnsureOffscreenWindow(void)
-{
-  if (sOffscreenWindow)
-    return;
-  sOffscreenWindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-  gtk_widget_realize(sOffscreenWindow);
-  sOffscreenFixed = gtk_fixed_new();
-  gtk_container_add(GTK_CONTAINER(sOffscreenWindow), sOffscreenFixed);
-  gtk_widget_realize(sOffscreenFixed);
-}
-
-/* static */
-void
-EmbedPrivate::DestroyOffscreenWindow(void)
-{
-  if (!sOffscreenWindow)
-    return;
-  gtk_widget_destroy(sOffscreenWindow);
-  sOffscreenWindow = 0;
-}
-
 char*
 EmbedPrivate::GetEncoding()
 {
@@ -1456,7 +1396,7 @@ EmbedPrivate::GetZoom(PRInt32 *aZoomLevel, nsISupports *aContext)
     rv = GetMarkupViewerByWindow(DOMWindow, getter_AddRefs(markupViewer));
     NS_ENSURE_SUCCESS(rv, rv);
     gboolean bval = FALSE;
-    if (gtk_moz_embed_common_get_pref (G_TYPE_BOOLEAN,"gtkmozembed.textzoom", &bval) && bval)
+    if (gtk_moz_embed_common_get_pref (G_TYPE_BOOLEAN, (gchar*)"gtkmozembed.textzoom", &bval) && bval)
       rv = markupViewer->GetTextZoom(&zoomLevelFloat);
     else
       rv = markupViewer->GetFullZoom(&zoomLevelFloat);
@@ -1494,7 +1434,7 @@ EmbedPrivate::SetZoom(PRInt32 aZoomLevel, nsISupports *aContext)
     rv = GetMarkupViewerByWindow(DOMWindow, getter_AddRefs(markupViewer));
     NS_ENSURE_SUCCESS(rv, rv);
     gboolean bval = FALSE;
-    if (gtk_moz_embed_common_get_pref (G_TYPE_BOOLEAN,"gtkmozembed.textzoom", &bval) && bval)
+    if (gtk_moz_embed_common_get_pref (G_TYPE_BOOLEAN, (gchar*)"gtkmozembed.textzoom", &bval) && bval)
       rv = markupViewer->SetTextZoom(zoomLevelFloat);
     else
       rv = markupViewer->SetFullZoom(zoomLevelFloat);
