@@ -109,8 +109,9 @@ EmbedProgress::Shutdown()
   return NS_OK;
 }
 
-NS_IMPL_ISUPPORTS2(EmbedProgress,
+NS_IMPL_ISUPPORTS3(EmbedProgress,
 		   nsIWebProgressListener,
+		   nsIWebProgressListener2,
 		   nsISupportsWeakReference)
 
 nsresult
@@ -200,6 +201,12 @@ EmbedProgress::OnStateChange(nsIWebProgress *aWebProgress,
       mPageDownloaded = PR_FALSE;
       mPagePainted = PR_FALSE;
       mShowProgressStopped = PR_FALSE;
+
+      nsCAutoString uriString;
+      RequestToURIString(aRequest, uriString);
+      if (!mOwner->mURI.Equals(uriString))
+        mOwner->SetURI(uriString.get());
+
       g_signal_emit(G_OBJECT(mOwner->mOwningWidget),
                     moz_embed_signals[NET_START], 0);
       NS_ENSURE_SUCCESS(EnsureAlive(mOwner), NS_ERROR_FAILURE);
@@ -374,6 +381,42 @@ EmbedProgress::OnSecurityChange(nsIWebProgress *aWebProgress,
   return NS_OK;
 }
 
+NS_IMETHODIMP
+EmbedProgress::OnRefreshAttempted(nsIWebProgress *aWebProgress,
+                                  nsIURI *aRefreshURI,
+                                  PRInt32 aMillis,
+                                  PRBool aSameURI,
+                                  PRBool *_retval NS_OUTPARAM)
+{
+  NS_ENSURE_ARG_POINTER(_retval);
+  *_retval = TRUE;      // Don't block this refresh
+
+  nsCAutoString uri;
+  aRefreshURI->GetSpec(uri);
+
+  g_signal_emit(G_OBJECT(mOwner->mOwningWidget),
+                moz_embed_signals[META_REFRESH], 
+                0,
+                uri.get(),
+                aSameURI,
+                aMillis,
+                &_retval);
+
+  return NS_OK;
+}
+
+NS_IMETHODIMP
+EmbedProgress::OnProgressChange64(nsIWebProgress *aWebProgress,
+                                  nsIRequest *aRequest,
+                                  PRInt64 aCurSelfProgress,
+                                  PRInt64 aMaxSelfProgress,
+                                  PRInt64 aCurTotalProgress,
+                                  PRInt64 aMaxTotalProgress)
+{
+  return NS_ERROR_NOT_IMPLEMENTED;
+}
+
+
 void
 EmbedProgress::InsertLogin(const char* username, const char* password)
 {
