@@ -304,6 +304,14 @@ gtk_moz_embed_class_init(GtkMozEmbedClass *klass)
                  gtkmozembed_BOOL__STRING,
                  G_TYPE_BOOLEAN, 1, G_TYPE_STRING |
                  G_SIGNAL_TYPE_STATIC_SCOPE);
+  moz_embed_signals[META_REFRESH] =
+    g_signal_new("meta_refresh",
+                 G_TYPE_FROM_CLASS(klass),
+                 G_SIGNAL_RUN_LAST,
+                 G_STRUCT_OFFSET(GtkMozEmbedClass, meta_refresh),
+                 NULL, NULL,
+                 gtkmozembed_BOOLEAN__STRING_BOOLEAN_INT,
+                 G_TYPE_BOOLEAN, 3, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_INT);
   moz_embed_signals[SIZE_TO] =
     g_signal_new("size_to",
                  G_TYPE_FROM_CLASS(klass),
@@ -606,7 +614,7 @@ gtk_moz_embed_destroy(GtkObject *object)
   if (embedPrivate) {
 
     // Destroy the widget only if it's been Init()ed.
-    if(embedPrivate->mInitialized || embedPrivate->mMozWindowWidget != 0) {
+    if(embedPrivate->mInitialized) {
       embedPrivate->Destroy();
     }
 
